# Nonlinear-Statistical-Coupling
* Library of core functions for the statistics of nonlinear systems.
* Methods were originally described in two papers [1,2] by Nelson and Umarov. 
* Subsequent developments [3-5] refined the definition of nonlinear statistical coupling to be the inverse of the degree of freedom and strength of fluctuations       defined by the relative variance of an expontial distribution with fluctuations in the standard deviation defined by a gamma distribution.
* Applications include a variety of Complex Decision Systems including information fusion [6-8], machine learning [9, 10], and generalized information metrics [11, 12]

References

[1] K. P. Nelson and S. Umarov, “The relationship between Tsallis statistics, the Fourier transform, and nonlinear coupling,” arXiv:0811.3777v1 [cs.IT], 2008.

[2] K. P. Nelson and S. Umarov, “Nonlinear statistical coupling,” Phys. A Stat. Mech. its Appl., vol. 389, no. 11, pp. 2157–2163, Jun. 2010.

[3] K. P. Nelson, “A definition of the coupled-product for multivariate coupled-exponentials,” Phys. A Stat. Mech. its Appl., vol. 422, pp. 187–192, Mar. 2015.

[4] K. P. Nelson, S. R. Umarov, and M. A. Kon, “On the average uncertainty for systems with nonlinear coupling,” Phys. A Stat. Mech. its Appl., vol. 468, pp. 30–43, 2017.

[5] K. P. Nelson, M. A. Kon, and S. R. Umarov, “Use of the geometric mean as a statistic for the scale of the coupled Gaussian distributions,” Physica A, vol. 515, pp. 248–257, 2019.

[6] K. P. Nelson, B. J. Scannell, and H. Landau, “A Risk Profile for Information Fusion Algorithms,” Entropy, vol. 13, no. 8, pp. 1518–1532, 2011.

[7] K. P. Nelson, B. J. Scannell, and H. Landau. "Risk management for object identification." U.S. Patent No. 8,595,177. 26 Nov. 2013.

[8] K. P. Nelson, M. Barbu, and B. J. Scannell, “Probabilistic graphs using coupled random variables,” in SPIE Sensing Technology & Applications, 2014, p. 911903.

[9] S. Cao, J. Li, K. P. Nelson, and M. A. Kon, “Coupled VAE: Improved Accuracy and Robustness of a Variational Autoencoder,” arXiv:1906.00536[cs.LG], vol. 1, pp. 1–19, Jun. 2019.

[10] C. A. George, E. A. Barrera, and K. P. Nelson, “Applying the Decisiveness and Robustness Metrics to Convolutional Neural Networks,” arXiv:2006.00058[cs.LG], May 2020.

[11] K. P. Nelson, “Reduced Perplexity: A simplified perspective on assessing probabilistic forecasts,” in Advances in Info-Metrics, M. Chen, J. M. Dunn, A. Golan, and A. Ullah, Eds. Oxford University Press, 2020.

[12] K. P. Nelson, “Assessing Probabilistic Inference by Comparing the Generalized Mean of the Model and Source Probabilities,” Entropy, vol. 19, no. 6, p. 286, Jun. 2017.
